@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: clamav-update.pl,v 1.41 2007/12/13 01:29:12 okamura Exp $
+# $Id: clamav-update.pl,v 1.47 2010/04/24 02:27:52 okamura Exp $
 
 =head1 NAME
 
@@ -513,6 +513,18 @@ sub CheckSecurity {
 	return $ok; 
 }
 
+sub StringFromTemplateHash {
+	my	(%template) = @_;
+	my	$string = $template{template};
+	
+	while (my ($name, $value) = each %{$template{params}}) {
+		$value = ${$value};
+		$string =~ s/\Q$name\E/$value/g;
+	}
+
+	return $string;
+}
+
 #### Build-In Phase Specifier ####
 
 # General
@@ -542,13 +554,26 @@ sub PhaseSpecifier4General {
 	# working directory (not specified)
 	$Phase{download}->{workdir} = undef;
 	# command sequence
-	$Phase{download}->{method} = [
-		# curl --silent -o DST/NAME-VERSION.EXT SRC/NAME-VERSION.EXT
-		['curl', '--silent', '-o',
-			"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}",
-			"$Setting{option}->{src}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}"
-		],
-	];
+	if (ref($Setting{option}->{src}) eq 'HASH') {
+		my	$src = StringFromTemplateHash(%{$Setting{option}->{src}});
+
+		$Phase{download}->{method} = [
+			# curl --silent --location -o DST/NAME-VERSION.EXT SRC
+			['curl', '--silent', '--location', '-o',
+				"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}",
+				$src
+			],
+		];
+	}
+	else {
+		$Phase{download}->{method} = [
+			# curl --silent --location -o DST/NAME-VERSION.EXT SRC/NAME-VERSION.EXT
+			['curl', '--silent', '--location', '-o',
+				"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}",
+				"$Setting{option}->{src}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}"
+			],
+		];
+	}
 	# rollback command sequence.
 	$Phase{download}->{rollback} = [
 		# rm -f DST/NAME-VERSION.EXT
@@ -743,7 +768,7 @@ sub PhaseSpecifier4PkgOnDmg {
 #	2. extract it.
 #	3. copy files
 #	SAMPLE CONFIGURATION:
-#		$Setting{version}->{latest}->{command} = [qw(curl --silent http://clamav-update.sourceforge.jp/release/clamav-update-2/version.txt)];
+#		$Setting{version}->{latest}->{command} = [qw(curl --silent --location http://clamav-update.sourceforge.jp/release/clamav-update-2/version.txt)];
 #		$Setting{version}->{latest}->{regexp} = qr/^(\d+(?:\.\d+)*)\s*$/;
 #		$Setting{version}->{current}->{command} = [qw(clamav-update.pl --version)];
 #		$Setting{version}->{current}->{regexp} = qr/^(?s-im)clamav-update\.pl v(\d+(?:\.\d+)*)\s+.*$/;
@@ -762,13 +787,13 @@ sub PhaseSpecifier4ClamavUpdate4ClamXav {
 		sub {
 			my	$releaseID;
 	
-			$releaseID = ReadCommandResult(qw(curl --silent http://clamav-update.sourceforge.jp/release/clamav-update-2/release_id.txt));
+			$releaseID = ReadCommandResult(qw(curl --silent --location http://clamav-update.sourceforge.jp/release/clamav-update-2/release_id.txt));
 			return 0	unless (defined($releaseID));
 			chomp $releaseID;
 			Log 'debug', 'release ID is %s', $releaseID;
 
 			return DoCommand(
-				'curl', '--silent', '-o',
+				'curl', '--silent', '--location', '-o',
 				"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}",
 				"$Setting{option}->{src}/$releaseID/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}"
 			);
@@ -792,7 +817,7 @@ sub PhaseSpecifier4ClamavUpdate4ClamXav {
 #	2. extract it.
 #	3. copy files
 #	SAMPLE CONFIGURATION:
-#		$Setting{version}->{latest}->{command} = [qw(curl --silent http://clamav-update.sourceforge.jp/release/clamav-update-2/version.txt)];
+#		$Setting{version}->{latest}->{command} = [qw(curl --silent --location http://clamav-update.sourceforge.jp/release/clamav-update-2/version.txt)];
 #		$Setting{version}->{latest}->{regexp} = qr/^(\d+(?:\.\d+)*)\s*$/;
 #		$Setting{version}->{current}->{command} = [qw(clamav-update.pl --version)];
 #		$Setting{version}->{current}->{regexp} = qr/^(?s-im)clamav-update\.pl v(\d+(?:\.\d+)*)\s+.*$/;
@@ -823,7 +848,7 @@ sub PhaseSpecifier4ClamavUpdate {
 #-------------------------------------------------------------------------------
 # グローバル変数初期値
 #-------------------------------------------------------------------------------
-$Version = 'clamav-update.pl v2.2.4';
+$Version = 'clamav-update.pl v2.2.7';
 
 %ErrorCode = (
 	arguments		=> 1,
@@ -876,7 +901,6 @@ $SyslogOpened = 0;
 		},
 	},
 	option	=> {
-		src		=> 'http://jaist.dl.sourceforge.net/sourceforge/clamav',
 		dst		=> tempdir(CLEANUP => 1),
 		name	=> 'clamav',
 		ext		=> 'tar.gz',
@@ -891,6 +915,14 @@ $SyslogOpened = 0;
 		specifier	=> undef,
 	},
 );
+$Setting{option}->{src} = {
+	template	=> 'http://jaist.dl.sourceforge.net/project/${NAME}/${NAME}/${VERSION}/${NAME}-${VERSION}.${EXT}',
+	params		=> {
+		'${NAME}'		=> \$Setting{option}->{name},
+		'${VERSION}'	=> \$LatestVersion,
+		'${EXT}'		=> \$Setting{option}->{ext},
+	},
+};
 
 %Phase = ();
 
@@ -1038,7 +1070,7 @@ GetOptions(
 		PrepareLogging();
 		print <<EOF;
 $Version
-Copyright (C) 2006-2007 OKAMURA Yuji, All rights reserved.
+Copyright (C) 2006-2009 OKAMURA Yuji, All rights reserved.
 This is free software; see the source for copying conditions. There is NO 
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 EOF
@@ -1181,6 +1213,18 @@ Reference of Configuration: L<http://clamav-update.sourceforge.jp/docs/clamav-up
 
 =over 4
 
+=item v2.2.7
+
+* Fix ticket #21446
+
+=item v2.2.6
+
+* $Setting{option}->{src} came to be able to describe a more complex download origin as a hush.
+
+=item v2.2.5
+
+* Support redirection response from web server.
+
 =item v2.2.4
 
  * The function PhaseSpecifier4ClamavUpdate is improved for FreeBSD 6.2.
