@@ -15,10 +15,13 @@ UsingClamd=0
 ClamdRestartCommand='[qw(/etc/rc.d/init.d/clamd restart)]'
 UsingFreshclam=0
 FreshclamRestartCommand='[qw(/etc/rc.d/init.d/freshclam restart)]'
-ClamavDownloadFrom=http://jaist.dl.sourceforge.net/sourceforge/clamav
+ClamavDownloadFrom=http://jaist.dl.sourceforge.net/project/
 DownloadFrom=http://osdn.dl.sourceforge.jp/clamav-update
 AdminGroup=0
 
+if [ $debug -ne 0 ]; then
+	echo $0 $*
+fi
 
 #### Check Source Directory ####
 if [ -f "$srcdir/clamav-update.pl" -a -x "$srcdir/clamav-update.pl" -a -f "$srcdir/clamav-update-update.conf" -a -f "$srcdir/template/clamav-update.conf" ]; then
@@ -60,40 +63,8 @@ Known values for OPTION are:
     	Change base URL of ClamAV source archive file.
     	default: $ClamavDownloadFrom
     	Following URLs are avairable
-            http://jaist.dl.sourceforge.net/sourceforge/clamav
+            http://jaist.dl.sourceforge.net/project/
                 Asia: Ishikawa, Japan
-            http://nchc.dl.sourceforge.net/sourceforge/clamav
-                Asia: Tainan, Taiwan
-            http://optusnet.dl.sourceforge.net/sourceforge/clamav
-                Australia: Sydney, Australia
-            http://belnet.dl.sourceforge.net/sourceforge/clamav
-                Europe: Brussels, Belgium
-            http://switch.dl.sourceforge.net/sourceforge/clamav
-                Europe: Lausanne, Switzerland
-            http://puzzle.dl.sourceforge.net/sourceforge/clamav
-                Europe: Bern, Switzerland
-            http://mesh.dl.sourceforge.net/sourceforge/clamav
-                Europe: Duesseldorf, Germany
-            http://dfn.dl.sourceforge.net/sourceforge/clamav
-                Europe: Berlin, Germany
-            http://heanet.dl.sourceforge.net/sourceforge/clamav
-                Europe: Dublin, Ireland
-            http://garr.dl.sourceforge.net/sourceforge/clamav
-                Europe: Bologna, Italy
-            http://surfnet.dl.sourceforge.net/sourceforge/clamav
-                Europe: Amsterdam, The Netherlands
-            http://kent.dl.sourceforge.net/sourceforge/clamav
-                Europe: Kent, UK
-            http://superb-east.dl.sourceforge.net/sourceforge/clamav
-                North America: McLean, Virginia
-            http://superb-west.dl.sourceforge.net/sourceforge/clamav
-                North America: Seattle, Washington
-            http://internap.dl.sourceforge.net/sourceforge/clamav
-                North America: San Jose, CA
-            http://easynews.dl.sourceforge.net/sourceforge/clamav
-                North America: Phoenix, AZ
-            http://ufpr.dl.sourceforge.net/sourceforge/clamav
-                South America: Curitiba, Brazil
     --download-from=URL
     	Change base URL of clamav-update archive file.
     	default: $DownloadFrom
@@ -648,10 +619,10 @@ cat "$srcdir/template/clamav-update.conf" \
 	fi
 ) \
 | (
-	if [ "$ClamavDownloadFrom" = 'http://jaist.dl.sourceforge.net/sourceforge/clamav' ]; then
-		sed "s/%DownloadFrom%/#\$Setting{option}->{src} = 'http:\/\/jaist.dl.sourceforge.net\/sourceforge\/clamav';/g"
+	if [ "$ClamavDownloadFrom" = 'http://jaist.dl.sourceforge.net/project/' ]; then
+		sed "s/%DownloadFrom%/#\$Setting{option}->{src}->{template} = '$regClamavDownloadFrom\${NAME}\/\${NAME}\/\${VERSION}\/\${NAME}-\${VERSION}.\${EXT}';/g"
 	else
-		sed "s/%DownloadFrom%/\$Setting{option}->{src} = '$regClamavDownloadFrom';/g"
+		sed "s/%DownloadFrom%/\$Setting{option}->{src}->{template} = '$regClamavDownloadFrom\${NAME}\/\${NAME}\/\${VERSION}\/\${NAME}-\${VERSION}.\${EXT}';/g"
 	fi
 ) \
 > "$tempfile1"
